@@ -9,7 +9,7 @@ import matplotlib.cm as cm
 
 from sunpy.cm import color_tables as ct
 
-__all__ = ['get_cmap', 'show_colormaps']
+__all__ = ['get_cmap', 'show_colormaps', 'cmlist']
 
 sdoaia94 = ct.aia_color_table(94)
 sdoaia131 = ct.aia_color_table(131)
@@ -33,6 +33,9 @@ soholasco3 = ct.lasco_color_table(3)
 stereocor1 = ct.cor_color_table(1)
 stereocor2 = ct.cor_color_table(2)
 
+stereohi1 = ct.stereo_hi_color_table(1)
+stereohi2 = ct.stereo_hi_color_table(2)
+
 yohkohsxtal = ct.sxt_color_table('al')
 yohkohsxtwh = ct.sxt_color_table('wh')
 
@@ -73,6 +76,8 @@ cmlist = {
           'soholasco3': soholasco3,
           'stereocor1': stereocor1,
           'stereocor2': stereocor2,
+          'stereohi1': stereohi1,
+          'stereohi2': stereohi2,
           'rhessi': cm.jet,  # pylint: disable=E1101
           'yohkohsxtal': yohkohsxtal,
           'yohkohsxtwh': yohkohsxtwh,
@@ -93,8 +98,11 @@ cmlist = {
           'hmimag': hmimag
           }
 
+# Register the colormaps with matplotlib so plt.get_cmap('sdoaia171') works
+for name, cmap in cmlist.items():
+    cm.register_cmap(name=name, cmap=cmap)
 
-def get_cmap(name='sdoaia94'):
+def get_cmap(name):
     """Get a colormap.
 
     Parameters
@@ -122,7 +130,7 @@ def get_cmap(name='sdoaia94'):
     if name in cmlist:
         return cmlist.get(name)
     else:
-        raise ValueError("Colormap %s is not recognized" % name)
+        raise ValueError("Colormap {name!s} is not recognized".format(name=name))
 
 
 def show_colormaps():
