@@ -12,32 +12,34 @@ try:
     import skimage.transform
     scikit_image_not_found = False
 except ImportError:  # pragma: no cover
+    warnings.warn("scikit-image could not be imported. Image rotation will use scipy",
+                  ImportWarning)
     scikit_image_not_found = True  # pragma: no cover
 
 __all__ = ['affine_transform']
 
+
 def affine_transform(image, rmatrix, order=3, scale=1.0, image_center=None,
                      recenter=False, missing=0.0, use_scipy=False):
     """
-    Rotates, shifts and scales an image using :func:`skimage.transform.warp`, or
-    :func:`scipy.ndimage.interpolation.affine_transform` if specified. Falls back to
-    the scipy function if scikit-image can't be imported.
+    Rotates, shifts and scales an image using :func:`skimage.transform.warp`,
+    or :func:`scipy.ndimage.interpolation.affine_transform` if specified. Falls
+    back to the scipy function if scikit-image can't be imported.
 
     Parameters
     ----------
-    image : ndarray
+    image : `numpy.ndarray`
         2D Image to be rotated.
     rmatrix : 2x2
         Linear transformation rotation matrix.
     order : int 0-5
         Interpolation order to be used. When using scikit-image this parameter
-        is passed into :func:`skimage.transform.warp`.
-        The default value of order 3 is a bicubic interpolation when using
-        :func:`skimage.transform.warp` and a cubic spline interpolation
-        when using :func:`scipy.ndimage.interpolation.affine_transform`.
+        is passed into :func:`skimage.transform.warp` (e.g., 3 corresponds to
+        bi-cubic interpolation).
         When using scipy it is passed into
         :func:`scipy.ndimage.interpolation.affine_transform` where it controls
         the order of the spline.
+        Default: 3
     scale : float
         A scale factor for the image. Default is no scaling.
     image_center : tuple
@@ -51,7 +53,7 @@ def affine_transform(image, rmatrix, order=3, scale=1.0, image_center=None,
     use_scipy : bool
         Force use of :func:`scipy.ndimage.interpolation.affine_transform`.
         Will set all NaNs in image to zero before doing the transform.
-        Default: False unless sckit-image is not installed.
+        Default: False, unless scikit-image can't be imported
 
     Returns
     -------
@@ -59,28 +61,27 @@ def affine_transform(image, rmatrix, order=3, scale=1.0, image_center=None,
 
     Notes
     -----
-    This function is used throughout the SunPy code base as an equivalent to
-    the IDL's rot() function. However, this function does not use the same
-    algorithm as the IDL rot() function.
+    This algorithm uses an affine transformation as opposed to a polynomial
+    geometrical transformation, which by default is :func:`skimage.transform.warp`.
+    One can specify using :func:`scipy.ndimage.interpolation.affine_transform` as
+    an alternative affine transformation.  The two transformations use different
+    algorithms and thus do not give identical output.
+
+    When using for :func:`skimage.transform.warp` with order >= 4 or using
+    :func:`scipy.ndimage.interpolation.affine_transform` at all, NaN values will
+    replaced with zero prior to rotation.  No attempt is made to retain the NaN
+    values.
+
+    Input arrays with integer data are cast to float64 and can be re-cast using
+    :func:`numpy.ndarray.astype` if desired.
+
+    Although this function is analogous to the IDL's rot() function, it does not
+    use the same algorithm as the IDL rot() function.
     IDL's rot() calls the `POLY_2D <http://www.exelisvis.com/docs/poly_2d.html>`_
     method to calculate the inverse mapping of original to target pixel
-    coordinates. This is a polynominal geometrical transformation.
+    coordinates. This is a polynomial geometrical transformation.
     Then optionally it uses a bicubic convolution interpolation
     algorithm to map the original to target pixel values.
-
-    This algorithm uses an affine transformation as opposed to a polynomial
-    geometrical transformation. It then defaults to a bicubic convolution
-    interpolation.
-
-    The two affine transform routines this method,
-    :func:`scipy.ndimage.interpolation.affine_transform` and
-    :func:`skimage.transform.warp` do not use the same interpolation
-    algorithm and therefore should not be expected to give identical output,
-    the scikit-image routines are preferred.
-
-    No direct comparision between this function and the IDL rot() function has
-    been performed as it is a different transformation, however both are
-    assumed to be mathamatically vaild.
     """
 
     rmatrix = rmatrix / scale
@@ -103,7 +104,7 @@ def affine_transform(image, rmatrix, order=3, scale=1.0, image_center=None,
 
     if use_scipy or scikit_image_not_found:
         if np.any(np.isnan(image)):
-            warnings.warn("Setting NaNs to 0 for SciPy rotation", Warning)
+            warnings.warn("Setting NaNs to 0 for SciPy rotation", RuntimeWarning)
         # Transform the image using the scipy affine transform
         rotated_image = scipy.ndimage.interpolation.affine_transform(
                 np.nan_to_num(image).T, rmatrix, offset=shift, order=order,
@@ -119,15 +120,30 @@ def affine_transform(image, rmatrix, order=3, scale=1.0, image_center=None,
         # Transform the image using the skimage function
         # Image data is normalised because warp() requires an array of values
         # between -1 and 1.
-        adjusted_image = np.copy(image)
+        if np.issubdtype(image.dtype, np.integer):
+            warnings.warn("Input integer data has been cast to float64", RuntimeWarning)
+            adjusted_image = image.astype(np.float64)
+        else:
+            adjusted_image = image.copy()
+        if np.any(np.isnan(adjusted_image)) and order >= 4:
+            warnings.warn("Setting NaNs to 0 for higher-order scikit-image rotation",
+                          RuntimeWarning)
+            adjusted_image = np.nan_to_num(adjusted_image)
+
         im_min = np.nanmin(adjusted_image)
         adjusted_image -= im_min
         im_max = np.nanmax(adjusted_image)
-        adjusted_image /= im_max
+        if im_max > 0:
+            adjusted_image /= im_max
+            adjusted_missing = (missing - im_min) / im_max
+        else:
+            adjusted_missing = missing - im_min
+
         rotated_image = skimage.transform.warp(adjusted_image, tform, order=order,
-                                               mode='constant', cval=missing)
+                                               mode='constant', cval=adjusted_missing)
 
-
-        rotated_image *= im_max
+        if im_max > 0:
+            rotated_image *= im_max
         rotated_image += im_min
+
     return rotated_image
