@@ -51,6 +51,6 @@ def SJI_to_cube(filename, start=0, stop=None, hdu=0):
     iris_cube = sunpy.map.Map(zip(datas,headers),cube=True)
     #Set the date/time
     for i,m in enumerate(iris_cube):
-        m.meta['DATE-OBS'] = splits[i].center().isoformat()
+        m.meta['DATE-OBS'] = splits[i].center.isoformat()
 
     return iris_cube
