@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from sunpy.util.odict import OrderedDict
+from collections import OrderedDict
 
 __all__ = ['FileHeader']
 
