@@ -49,8 +49,8 @@ class GOESLightCurve(LightCurve):
         .. plot::
 
             from sunpy import lightcurve as lc
-            from sunpy.time import TimeRange
-            goes = lc.GOESLightCurve.create(TimeRange('2012/06/01', '2012/06/05'))
+            from sunpy.data.sample import GOES_LIGHTCURVE
+            goes = lc.GOESLightCurve.create(GOES_LIGHTCURVE)
             goes.peek()
 
         Parameters
@@ -120,25 +120,25 @@ class GOESLightCurve(LightCurve):
         """Parses the query time to determine which GOES satellite to use."""
 
         goes_operational = {
-        2: TimeRange('1981-01-01', '1983-04-30'),
-        5: TimeRange('1983-05-02', '1984-07-31'),
-        6: TimeRange('1983-06-01', '1994-08-18'),
-        7: TimeRange('1994-01-01', '1996-08-13'),
-        8: TimeRange('1996-03-21', '2003-06-18'),
-        9: TimeRange('1997-01-01', '1998-09-08'),
-        10: TimeRange('1998-07-10', '2009-12-01'),
-        11: TimeRange('2006-06-20', '2008-02-15'),
-        12: TimeRange('2002-12-13', '2007-05-08'),
+        2: TimeRange('1980-01-04', '1983-05-01'),
+        5: TimeRange('1983-05-02', '1984-08-01'),
+        6: TimeRange('1983-06-01', '1994-08-19'),
+        7: TimeRange('1994-01-01', '1996-08-14'),
+        8: TimeRange('1996-03-21', '2003-06-19'),
+        9: TimeRange('1997-01-01', '1998-09-09'),
+        10: TimeRange('1998-07-10', '2009-12-02'),
+        11: TimeRange('2006-06-20', '2008-02-16'),
+        12: TimeRange('2002-12-13', '2007-05-09'),
         13: TimeRange('2006-08-01', '2006-08-01'),
-        14: TimeRange('2009-12-02', '2010-10-04'),
+        14: TimeRange('2009-12-02', '2010-11-05'),
         15: TimeRange('2010-09-01', datetime.datetime.utcnow())}
 
         sat_list = []
         for sat_num in goes_operational:
-            if ((start > goes_operational[sat_num].start and
-                 start < goes_operational[sat_num].end and
-                (end > goes_operational[sat_num].start and
-                 end < goes_operational[sat_num].end))):
+            if ((start >= goes_operational[sat_num].start and
+                 start <= goes_operational[sat_num].end and
+                (end >= goes_operational[sat_num].start and
+                 end <= goes_operational[sat_num].end))):
                 # if true then the satellite with sat_num is available
                 sat_list.append(sat_num)
 
