@@ -20,17 +20,12 @@ __all__ = ['LogicalLightCurve']
 # start and end time of each TimeRange object are labeled 'True'.
 class LogicalLightCurve(LightCurve):
     """
-    Logical LightCurve.
-
-    Originated from a need to analyze the times of HEK
-    results, where 'True' indicates an event was observed, and 'False'
-    indicates an event was not observed.
+    Logical LightCurve with only True and False values.
 
     Examples
     --------
     >>> import sunpy.lightcurve as lightcurve
     >>> import datetime
-
     >>> base = datetime.datetime.today()
     >>> dates = [base - datetime.timedelta(minutes=x) for x in range(0, 24 * 60)]
     >>> z = [True for x in range(0, 24 * 60)]
@@ -38,13 +33,18 @@ class LogicalLightCurve(LightCurve):
     """
 
     def complement(self):
-        """ Define the complement of the passed lightcurve """
+        """Return the logical complement of the original lightcurve."""
         return LogicalLightCurve.create(np.invert(self.data),
                                         header = self.header)
 
     def times(self):
-        """Label all the periods of time that have the value 'True'. Return
-        a list of TimeRange objects """
+        """Returns a list of time ranges where values are True.
+
+        Returns
+        -------
+        outtr : `~sunpy.time.TimeRange` array
+            An array of time ranges
+        """
 
         labeling = label(self.data)
         timeranges = []
