@@ -6,6 +6,8 @@ from __future__ import absolute_import
 
 import matplotlib.pyplot as plt
 
+import astropy.units as u
+
 from sunpy.map import GenericMap
 
 from sunpy.util import expand_list
@@ -15,6 +17,7 @@ __all__ = ['CompositeMap']
 __author__ = "Keith Hughitt"
 __email__ = "keith.hughitt@nasa.gov"
 
+
 class CompositeMap(object):
     """
     CompositeMap(map1 [,map2,..])
@@ -23,7 +26,7 @@ class CompositeMap(object):
 
     Parameters
     ----------
-    args : [sunpy.map | string]
+    args : [`~sunpy.map.Map` | string]
         One or more map of filepaths
 
     Methods
@@ -31,29 +34,29 @@ class CompositeMap(object):
     add_map(map, zorder=None, alpha=1, levels=False)
         Adds a map to the CompositeMap
     remove_map(index)
-        Removes and returns the map with the given index
+        Removes and returns the map with the given index.
     list_maps()
-        Prints a list of the currently included maps
+        Prints a list of the currently included maps.
     get_alpha(index=None)
-        Gets the alpha-channel value for a layer in the composite image
+        Returns the alpha-channel value for a layer in the composite image
     get_zorder(index=None)
-        Gets the layering preference (z-order) for a map within the composite.
+        Returns the layering preference (z-order) for a map within the composite.
     get_colors(index=None)
-        Gets the colors for a map within the CompositeMap.
+        Returns the colors for a map within the CompositeMap.
     get_norm(index=None)
-        Gets the normalization for a map within the CompositeMap.
+        Returns the normalization for a map within the CompositeMap.
     get_levels(index=None)
-        Gets the list of contour levels for a map within the CompositeMap
+        Returns the list of contour levels for a map within the CompositeMap
     set_norm(self, index, norm)
-        Sets the norm for a layer in the composite image
+        Sets the norm for a layer in the composite image.
     set_levels(index, levels, percent=False)
-        Sets the contour levels for a layer in the CompositeMap
+        Sets the contour levels for a layer in the CompositeMap.
     set_colors(index=None, cm)
-        Sets the color map for a layer in the CompositeMap
+        Sets the color map for a layer in the CompositeMap.
     set_alpha(index=None, alpha)
-        Sets the alpha-channel value for a layer in the CompositeMap
+        Sets the alpha-channel value for a layer in the CompositeMap.
     set_zorder(index=None, zorder)
-        Set the layering preference (z-order) for a map within the CompositeMap
+        Set the layering preference (z-order) for a map within the CompositeMap.
     plot(figure=None, overlays=None, draw_limb=False, gamma=1.0,
     draw_grid=False, colorbar=True, basic_plot=False,title="SunPy Plot",
     matplot_args)
@@ -61,24 +64,18 @@ class CompositeMap(object):
 
     Examples
     --------
-    >>> import sunpy
-    >>> sunpy.Map(sunpy.AIA_171_IMAGE, sunpy.RHESSI_IMAGE, composite=True)
-    >>> comp_map = sunpy.Map(sunpy.AIA_171_IMAGE, sunpy.EIT_195_IMAGE,
-                             composite=True)
-    >>> comp_map.add_map(sunpy.Map(sunpy.RHESSI_IMAGE))
-    >>> comp_map.peek()
+    >>> import sunpy.map
+    >>> import sunpy.data
+    >>> sunpy.data.download_sample_data(overwrite=False)   # doctest: +SKIP
+    >>> import sunpy.data.sample
+    >>> comp_map = sunpy.map.Map(sunpy.data.sample.AIA_171_IMAGE,
+    ...                          sunpy.data.sample.EIT_195_IMAGE,
+    ...                          composite=True)
+    >>> comp_map.add_map(sunpy.map.Map(sunpy.data.sample.RHESSI_IMAGE))
+    >>> comp_map.peek()   # doctest: +SKIP
 
     """
     def __init__(self, *args, **kwargs):
-        """
-        Create a CompositeMap
-
-        Parameters
-        ----------
-        Maps: SunPy Maps
-            A sequence of maps
-        """
-
         self._maps = expand_list(args)
 
         for m in self._maps:
@@ -98,22 +95,21 @@ class CompositeMap(object):
             m.levels = levels[i]
 
     def add_map(self, amap, zorder=None, alpha=1, levels=False):
-        """Adds a map to the CompositeMap
+        """Adds a map to the CompositeMap.
 
         Parameters
         ----------
-        map : sunpy.map
+        map : `~sunpy.map.GenericMap` or subclass
             Map instance to be added
-        zorder : int
+        zorder : `int`
             The index to use when determining where the map should lie along
             the z-axis; maps with higher z-orders appear above maps with lower
             z-orders.
-        alpha : float
+        alpha : `float`
             Opacity at which the map should be displayed. An alpha value of 0
             results in a fully transparent image while an alpha value of 1
             results in a fully opaque image. Values between result in semi-
             transparent images.
-
         """
         if zorder is None:
             zorder = max([m.zorder for m in self._maps]) + 10
@@ -125,27 +121,51 @@ class CompositeMap(object):
         self._maps.append(amap)
 
     def remove_map(self, index):
-        """Removes and returns the map with the given index"""
+        """Removes and returns the map with the given index.
+
+        Parameters
+        ----------
+        index : `int`
+            The index of the map in the composite map.
+
+        Returns
+        -------
+        `sunpy.map.CompositeMap`
+            A composite map with the map indexed by 'index' removed from the
+            composite map.
+        """
         return self._maps.pop(index)
 
     def list_maps(self):
-        """Prints a list of the currently included maps"""
+        """Prints a list of the currently included maps."""
         print [m.__class__ for m in self._maps]
 
     def get_map(self, index):
-        """ Returns the map with given index """
+        """Returns the map with given index """
         return self._maps[index]
 
     def get_alpha(self, index=None):
-        """Gets the alpha-channel value for a layer in the composite image"""
+        """Returns the alpha-channel value for a layer in the composite image"""
         if index is None:
             return [_map.alpha for _map in self._maps]
         else:
             return self._maps[index].alpha
 
     def get_zorder(self, index=None):
-        """Gets the layering preference (z-order) for a map within the
+        """Returns the layering preference (z-order) for a map within the
         composite.
+
+        Parameters
+        ----------
+        index : {`int` | None}
+            The index of the map in the composite map.
+
+        Returns
+        -------
+        {`float` | `list`}
+            The layering order (z-order) of the map(s) in the composite
+            map.  If None then the layering order of all the maps is returned in
+            a list.
         """
         if index is None:
             return [_map.zorder for _map in self._maps]
@@ -153,15 +173,40 @@ class CompositeMap(object):
             return self._maps[index].zorder
 
     def get_colors(self, index=None):
-        """Gets the colors for a map within the compositemap."""
+        """Returns the colors for a map within the composite map.
+
+        Parameters
+        ----------
+        index : {`int` | None}
+            The index of the map in the composite map.
+
+        Returns
+        -------
+        {`sunpy.cm` | `list`}
+            The colormaps of the map(s) in the composite map.  If None then the
+            colormaps of all the maps are returned in a list.
+        """
+
         if index is None:
-            return [_map.cmap for _map in self._maps]
+            return [_map.plot_settings['cmap'] for _map in self._maps]
         else:
-            return self._maps[index].cmap
+            return self._maps[index].plot_settings['cmap']
 
     def get_mpl_color_normalizer(self, index=None):
-        """Gets the color normalizer for a map within the
+        """Returns the color normalizer for a map within the
         composite.
+
+        Parameters
+        ----------
+        index : {`int` | None}
+            The index of the map in the composite map.
+
+        Returns
+        -------
+        {color normalizer | `list`}
+            The color normalizer(s) of the map(s) in the composite map.
+            If None then the color normalizers of all the maps are returned in
+            a list.
         """
         if index is None:
             return [_map.mpl_color_normalizer for _map in self._maps]
@@ -169,8 +214,20 @@ class CompositeMap(object):
             return self._maps[index].mpl_color_normalizer
 
     def get_levels(self, index=None):
-        """Gets the list of contour levels for a map within the
+        """Returns the list of contour levels for a map within the
         composite.
+
+        Parameters
+        ----------
+        index : {`int` | None}
+            The index of the map in the composite map.
+
+        Returns
+        -------
+        `list`
+            A list of the contour levels of map at index 'index' in the
+            composite map.  If index is None, then the contour levels of all
+            the maps are returned as a list of lists.
         """
         if index is None:
             return [_map.levels for _map in self._maps]
@@ -178,77 +235,154 @@ class CompositeMap(object):
             return self._maps[index].levels
 
     def set_mpl_color_normalizer(self, index, norm):
-        """Sets the normalizer for a layer in the composite image."""
+        """Sets the color normalizer for a layer in the composite image.
+
+        Parameters
+        ----------
+        index : `int`
+            The index of the map in the composite map.
+
+        norm : a color normalizer
+            The function used to stretch the color table.
+
+        Returns
+        -------
+        `~sunpy.map.CompositeMap`
+            Sets the color normalizer of the map at index 'index' in the
+            composite map to the value given by 'norm'."""
         self._maps[index].mpl_color_normalizer = norm
 
     def set_levels(self, index, levels, percent=False):
-        """Sets the contour levels for a layer in the composite image"""
+        """
+        Sets the contour levels for a layer in the composite image.
+
+        Parameters
+        ----------
+        index : `int`
+            The index of the map in the composite map.
+
+        levels : array-like
+            The contour levels.
+
+        percent : `bool`
+            If True, the input 'levels' are interpreted as percentages relative
+            to the maximum value of the data in layer 'index' of the composite
+            map.  If False, the contour levels are set directly from 'levels'.
+
+        Returns
+        -------
+        `~sunpy.map.CompositeMap`
+            A composite map with contour levels 'levels' at layer 'index'.
+        """
         if percent is False:
             self._maps[index].levels = levels
         else:
             self._maps[index].levels = [self._maps[index].max()*level/100.0 for level in levels]
 
     def set_colors(self, index, cm):
-        """Sets the color map for a layer in the composite image"""
-        self._maps[index].cmap = cm
+        """Sets the color map for a layer in the composite image.
+
+        Parameters
+        ----------
+        index : `int`
+            The index of the map in the composite map.
+
+        cm : a color map
+            The contour levels.
+
+        Returns
+        -------
+        `~sunpy.map.CompositeMap`
+            A composite map with colormap 'cm' at layer 'index'.
+        """
+        self._maps[index].plot_settings['cmap'] = cm
 
     def set_alpha(self, index, alpha):
-        """Sets the alpha-channel value for a layer in the composite image"""
+        """Sets the alpha-channel value for a layer in the composite image.
+
+        Parameters
+        ----------
+        index : `int`
+            The index of the map in the composite map.
+
+        alpha : `float`
+            A float in the range 0 to 1.
+
+        Returns
+        -------
+        `~sunpy.map.CompositeMap`
+            A composite map with alpha-channel value 'alpha' at layer 'index'.
+        """
         if 0 <= alpha <= 1:
             self._maps[index].alpha = alpha
         else:
             raise OutOfRangeAlphaValue("Alpha value must be between 0 and 1.")
 
     def set_zorder(self, index, zorder):
-        """Set the layering preference (z-order) for a map within the
+        """Set the layering order (z-order) for a map within the
         composite.
+
+        Parameters
+        ----------
+        index : `int`
+            The index of the map in the composite map.
+
+        zorder : `int`
+            The layer order.
+
+        Returns
+        -------
+        `~sunpy.map.CompositeMap`
+            A composite map with the map at layer 'index' having layering order
+            'zorder'.
         """
         self._maps[index].zorder = zorder
 
     def draw_limb(self, index=None, axes=None):
-        """Draws a circle representing the solar limb
+        """Draws a circle representing the solar limb.
 
-            Parameters
-            ----------
-            index: integer
-                Map index to use to plot limb.
+        Parameters
+        ----------
+        index : `int`
+            Map index to use to plot limb.
 
-            axes: matplotlib.axes object or None
-                Axes to plot limb on or None to use current axes.
+        axes : `matplotlib.axes.Axes` or None
+            Axes to plot limb on or None to use current axes.
 
-            Returns
-            -------
-            matplotlib.axes object
+        Returns
+        -------
+        `matplotlib.axes.Axes`
         """
         if index is None:
             for i,amap in enumerate(self._maps):
-                if hasattr(amap,'rsun_arcseconds'):
+                if hasattr(amap,'rsun_obs'):
                     index = i
                     break
 
-        index_check = hasattr(self._maps[index],'rsun_arcseconds')
+        index_check = hasattr(self._maps[index],'rsun_obs')
         if not index_check or index is None:
             raise ValueError("Specified index does not have all the required attributes to draw limb.")
 
         return self._maps[index].draw_limb(axes=axes)
 
-    def draw_grid(self, index=None, axes=None, grid_spacing=20):
-        """Draws a grid over the surface of the Sun
+    @u.quantity_input(grid_spacing=u.deg)
+    def draw_grid(self, index=None, axes=None, grid_spacing=20*u.deg):
+        """Draws a grid over the surface of the Sun.
 
         Parameters
         ----------
-        index: integer
+        index: int
             Index to determine which map to use to draw grid.
 
-        axes: matplotlib.axes object or None
+        axes: `~matplotlib.axes.Axes` or None
             Axes to plot limb on or None to use current axes.
 
-        grid_spacing: float
+        grid_spacing : `float`
             Spacing (in degrees) for longitude and latitude grid.
 
         Returns
         -------
-        matplotlib.axes object
+        `matplotlib.axes.Axes` object
         """
         needed_attrs = ['rsun_meters', 'dsun', 'heliographic_latitude',
                             'heliographic_longitude']
@@ -265,65 +399,63 @@ class CompositeMap(object):
         ax = self._maps[index].draw_grid(axes=axes, grid_spacing=grid_spacing)
         return ax
 
-    def plot(self, axes=None, gamma=None, annotate=True, # pylint: disable=W0613
+    def plot(self, axes=None, annotate=True, # pylint: disable=W0613
              title="SunPy Composite Plot", **matplot_args):
         """Plots the composite map object using matplotlib
 
         Parameters
         ----------
-        axes: matplotlib.axes object or None
+
+        axes: `~matplotlib.axes.Axes` or None
             If provided the image will be plotted on the given axes. Else the
             current matplotlib axes will be used.
 
-        gamma : float
-            Gamma value to use for the color map
-
-        annotate : bool
+        annotate : `bool`
             If true, the data is plotted at it's natural scale; with
             title and axis labels.
 
-        **matplot_args : dict
+        **matplot_args : `dict`
             Matplotlib Any additional imshow arguments that should be used
-            when plotting the image.
+            when plotting.
 
         Returns
         -------
-        ret : List
+        ret : `list`
             List of axes image or quad contour sets that have been plotted.
         """
 
-        #Get current axes
+        # Get current axes
         if not axes:
             axes = plt.gca()
 
         if annotate:
             # x-axis label
-            if self._maps[0].coordinate_system['x'] == 'HG':
-                xlabel = 'Longitude [%s]' % self._maps[0].units['x']
+            if self._maps[0].coordinate_system.x == 'HG':
+                xlabel = 'Longitude [{lon}]'.format(lon=self._maps[0].units.x)
             else:
-                xlabel = 'X-position [%s]' % self._maps[0].units['x']
+                xlabel = 'X-position [{solx}]'.format(solx=self._maps[0].units.x)
 
             # y-axis label
-            if self._maps[0].coordinate_system['y'] == 'HG':
-                ylabel = 'Latitude [%s]' % self._maps[0].units['y']
+            if self._maps[0].coordinate_system.y == 'HG':
+                ylabel = 'Latitude [{lat}]'.format(lat=self._maps[0].units.y)
             else:
-                ylabel = 'Y-position [%s]' % self._maps[0].units['y']
+                ylabel = 'Y-position [{soly}]'.format(soly=self._maps[0].units.y)
 
             axes.set_xlabel(xlabel)
             axes.set_ylabel(ylabel)
 
             axes.set_title(title)
 
-        #Define a list of plotted objects
+        # Define a list of plotted objects
         ret = []
         # Plot layers of composite map
         for m in self._maps:
             # Parameters for plotting
             params = {
                 "origin": "lower",
-                "extent": m.xrange + m.yrange,
-                "cmap": m.cmap,
-                "norm": m.mpl_color_normalizer,
+                "extent": list(m.xrange.value) + list(m.yrange.value),
+                "cmap": m.plot_settings['cmap'],
+                "norm": m.plot_settings['norm'],
                 "alpha": m.alpha,
                 "zorder": m.zorder,
             }
@@ -337,36 +469,33 @@ class CompositeMap(object):
                 # Set data with values <= 0 to transparent
                 # contour_data = np.ma.masked_array(m, mask=(m <= 0))
                 ret.append(axes.contour(m.data, m.levels, **params))
-                #Set the label of the first line so a legend can be created
+                # Set the label of the first line so a legend can be created
                 ret[-1].collections[0].set_label(m.name)
 
         # Adjust axes extents to include all data
         axes.axis('image')
 
-        #Set current image (makes colorbar work)
+        # Set current image (makes colorbar work)
         plt.sci(ret[0])
         return ret
 
-    def peek(self, gamma=None, colorbar=True, basic_plot=False, draw_limb=True,
+    def peek(self, colorbar=True, basic_plot=False, draw_limb=True,
              draw_grid=False, **matplot_args):
-        """Displays the map in a new figure
+        """Displays the map in a new figure.
 
         Parameters
         ----------
-        gamma : float
-            Gamma value to use for the color map
-
-        colorbar : bool or int
+        colorbar : `bool` or `int`
             Whether to display a colorbar next to the plot.
             If specified as an integer a colorbar is plotted for that index.
 
-        basic_plot : bool
+        basic_plot : `bool`
             If true, the data is plotted by itself at it's natural scale; no
             title, labels, or axes are shown.
 
         **matplot_args : dict
             Matplotlib Any additional imshow arguments that should be used
-            when plotting the image.
+            when plotting.
         """
 
         # Create a figure and add title and axes
@@ -401,8 +530,6 @@ class CompositeMap(object):
 
         figure.show()
 
-        return figure
-
 
 class OutOfRangeAlphaValue(ValueError):
     """Exception to raise when an alpha value outside of the range 0-1 is
