@@ -31,13 +31,15 @@ from sunpy.util.datatype_factory_base import ValidationFunctionError
 try:
     from sunpy.database.tables import DatabaseEntry
 except ImportError:
-    class DatabaseEntry:
+    class DatabaseEntry(object):
         pass
 
 __all__ = ['Map', 'MapFactory']
 
 class MapFactory(BasicRegistrationFactory):
     """
+    Map(*args, **kwargs)
+
     Map factory class.  Used to create a variety of Map objects.  Valid map types
     are specified by registering them with the factory.
 
@@ -45,47 +47,49 @@ class MapFactory(BasicRegistrationFactory):
     Examples
     --------
     >>> import sunpy.map
-    >>> mymap = sunpy.map.Map(sunpy.AIA_171_IMAGE)
+    >>> sunpy.data.download_sample_data(overwrite=False)   # doctest: +SKIP
+    >>> import sunpy.data.sample
+    >>> mymap = sunpy.map.Map(sunpy.data.sample.AIA_171_IMAGE)
 
     The SunPy Map factory accepts a wide variety of inputs for creating maps
 
     * Preloaded tuples of (data, header) pairs
 
-    >>> mymap = sunpy.map.Map((data, header))
+    >>> mymap = sunpy.map.Map((data, header))   # doctest: +SKIP
 
     headers are some base of `dict` or `collections.OrderedDict`, including `sunpy.io.header.FileHeader` or `sunpy.map.header.MapMeta` classes.
 
     * data, header pairs, not in tuples
 
-    >>> mymap = sunpy.map.Map(data, header)
+    >>> mymap = sunpy.map.Map(data, header)   # doctest: +SKIP
 
     * File names
 
-    >>> mymap = sunpy.map.Map('file1.fits')
+    >>> mymap = sunpy.map.Map('file1.fits')   # doctest: +SKIP
 
     * All fits files in a directory by giving a directory
 
-    >>> mymap = sunpy.map.Map('local_dir/sub_dir')
+    >>> mymap = sunpy.map.Map('local_dir/sub_dir')   # doctest: +SKIP
 
     * Some regex globs
 
-    >>> mymap = sunpy.map.Map('eit_*.fits')
+    >>> mymap = sunpy.map.Map('eit_*.fits')   # doctest: +SKIP
 
     * URLs
 
-    >>> mymap = sunpy.map.Map(url_str)
+    >>> mymap = sunpy.map.Map(url_str)   # doctest: +SKIP
 
     * DatabaseEntry
 
-    >>> mymap = sunpy.map.Map(db_result)
+    >>> mymap = sunpy.map.Map(db_result)   # doctest: +SKIP
 
     * Lists of any of the above
 
-    >>> mymap = sunpy.Map(['file1.fits', 'file2.fits', 'file3.fits', 'directory1/'])
+    >>> mymap = sunpy.map.Map(['file1.fits', 'file2.fits', 'file3.fits', 'directory1/'])   # doctest: +SKIP
 
     * Any mixture of the above not in a list
 
-    >>> mymap = sunpy.Map((data, header), data2, header2, 'file1.fits', url_str, 'eit_*.fits')
+    >>> mymap = sunpy.map.Map((data, header), data2, header2, 'file1.fits', url_str, 'eit_*.fits')   # doctest: +SKIP
     """
 
     def _read_file(self, fname, **kwargs):
@@ -199,7 +203,7 @@ class MapFactory(BasicRegistrationFactory):
 
             i += 1
         #TODO:
-        # In the end, if there are aleady maps it should be put in the same
+        # In the end, if there are already maps it should be put in the same
         # order as the input, currently they are not.
         return data_header_pairs, already_maps
 
@@ -258,7 +262,7 @@ class MapFactory(BasicRegistrationFactory):
         if cube:
             return MapCube(new_maps, **kwargs)
 
-        # If the list is meant to be a composite mape, instantiate one
+        # If the list is meant to be a composite map, instantiate one
         if composite:
             return CompositeMap(new_maps, **kwargs)
 
@@ -285,7 +289,7 @@ class MapFactory(BasicRegistrationFactory):
             else:
                 candidate_widget_types = [self.default_widget_type]
         elif n_matches > 1:
-            raise MultipleMatchError("Too many candidate types idenfitied ({0}).  Specify enough keywords to guarantee unique type identification.".format(n_matches))
+            raise MultipleMatchError("Too many candidate types identified ({0}).  Specify enough keywords to guarantee unique type identification.".format(n_matches))
 
         # Only one is found
         WidgetType = candidate_widget_types[0]
