@@ -1,16 +1,13 @@
-"""Test cases for IRISMap.
-This particular test file pertains to IRISMap.
+"""Test cases for SJIMap.
+This particular test file pertains to SJIMap.
 @Author: Pritish C. (VaticanCameos)
 """
 
 import os
 import glob
-import numpy as np
-
-import pytest
 
 from sunpy.map import Map
-from sunpy.map.sources.iris import IRISMap
+from sunpy.map.sources.iris import SJIMap
 from sunpy.map.mapbase import GenericMap
 import sunpy.data.test
 
@@ -20,20 +17,20 @@ irislist = Map(fitspath)
 
 # IRIS Tests
 def test_fitstoIRIS():
-    """Tests the creation of IRISMap using FITS."""
+    """Tests the creation of SJIMap using FITS."""
     for amap in irislist:
-        assert (isinstance(amap, (IRISMap, GenericMap)))
+        assert (isinstance(amap, (SJIMap, GenericMap)))
 
 def test_is_datasource_for():
-    """Test the is_datasource_for method of IRISMap.
+    """Test the is_datasource_for method of SJIMap.
     Note that header data to be provided as an argument
     can be a MapMeta object."""
     for amap in irislist:
-        if isinstance(amap, IRISMap):
+        if isinstance(amap, SJIMap):
             assert amap.is_datasource_for(amap.data, amap.meta)
 
 def test_observatory():
-    """Tests the observatory property of IRISMap."""
+    """Tests the observatory property of SJIMap."""
     for amap in irislist:
-        if isinstance(amap, IRISMap):
+        if isinstance(amap, SJIMap):
             assert amap.observatory == "IRIS"
