@@ -37,4 +37,4 @@ def test_observatory(createSWAP):
 
 def test_measurement(createSWAP):
     """Tests the measurement property of the SWAPMap object."""
-    assert createSWAP.measurement == 174
+    assert createSWAP.measurement.value == 174
