@@ -3,9 +3,9 @@
 import sunpy
 import sunpy.map
 #==============================================================================
-# Test, read, get_header and write through the file independant layer
+# Test, read, get_header and write through the file independent layer
 #==============================================================================
-class TestMapMeta():
+class TestMapMeta(object):
 
     def test_upcasing(self):
         meta = sunpy.map.MapMeta({'wibble':1, 'WOBBLE':2})
