@@ -16,7 +16,7 @@ from functools import partial
 from contextlib import closing
 from collections import defaultdict, deque
 
-import sunpy as spy
+import sunpy
 
 def default_name(path, sock, url):
     name = sock.headers.get('Content-Disposition', url.rsplit('/', 1)[-1])
@@ -130,7 +130,7 @@ class Downloader(object):
         server = self._get_server(url)
 
         # Create function to compute the filepath to download to if not set
-        default_dir = spy.config.get("downloads", "download_dir")
+        default_dir = sunpy.config.get("downloads", "download_dir")
 
         if path is None:
             path = partial(default_name, default_dir)
