@@ -13,13 +13,12 @@ __version__ = 'June 11th, 2013'
 
 import pytest
 
+from astropy import units as u
+
 from sunpy.net import hek
 from sunpy.net import vso
 from sunpy.net import hek2vso
 
-from sunpy.time import parse_time
-
-import numpy as np
 
 startTime = '2011/08/09 07:23:56'
 endTime = '2011/08/09 12:40:29'
@@ -41,23 +40,10 @@ def hek_client():
 def vso_client():
     vso.VSOClient()
 
-def test_wave_unit_catcher():
-    """Make sure that inter-unit conversion of wavelengths is accurate"""
-    # Implementing the example test cases
-    test_wavel = [
-        hek2vso.wave_unit_catcher(2.11e-06, 'cm'),
-        hek2vso.wave_unit_catcher(9.4e-07, 'cm'),
-        hek2vso.wave_unit_catcher(5e-08, 'mm')
-    ]
-    test_values = [211.0, 94.0, 0.5]
-
-    assert np.allclose(test_wavel, test_values, rtol=1e-05, atol=1e-8)
-
 @pytest.mark.online
 def test_translate_results_to_query():
     """Make sure that conversion of HEK results to VSO queries is accurate"""
     h = hek.HEKClient()
-    h2v = hek2vso.H2VClient()
     hek_query = h.query(hekTime, hekEvent)
     vso_query = hek2vso.translate_results_to_query(hek_query)
 
@@ -71,11 +57,10 @@ def test_translate_results_to_query():
 def test_vso_attribute_parse():
     """Make sure that Parsing of VSO attributes from HEK queries is accurate"""
     h = hek.HEKClient()
-    h2v = hek2vso.H2VClient()
     hek_query = h.query(hekTime, hekEvent)
     vso_query = hek2vso.vso_attribute_parse(hek_query[0])
 
-    # Cheking Time
+    # Checking Time
     # TODO
 
     # Checking Observatory
@@ -85,10 +70,10 @@ def test_vso_attribute_parse():
     assert vso_query[2].value == hek_query[0]['obs_instrument']
 
     # Checking Wavelength
-    assert vso_query[3].min == hek2vso.wave_unit_catcher(hek_query[0]['obs_meanwavel'], hek_query[0]['obs_wavelunit'])
-    assert vso_query[3].max == hek2vso.wave_unit_catcher(hek_query[0]['obs_meanwavel'], hek_query[0]['obs_wavelunit'])
-    assert vso_query[3].unit == 'Angstrom'
+    assert vso_query[3].min == hek_query[0]['obs_meanwavel'] * u.Unit(hek_query[0]['obs_wavelunit'])
+    assert vso_query[3].max == hek_query[0]['obs_meanwavel'] * u.Unit( hek_query[0]['obs_wavelunit'])
+    assert vso_query[3].unit == u.Unit('Angstrom')
 
-class TestH2VClient:
+class TestH2VClient(object):
     """Tests the H2V class"""
     # TODO
