@@ -1,12 +1,9 @@
 from __future__ import absolute_import
 
-import xml.etree.ElementTree
-
 import pytest
 
 from sunpy.net.helio import hec
 import sunpy.net.helio.parser as p
-from sunpy.net.helio import registry_links as RL
 
 def test_suds_unwrapper():
     suds_output = """<?xml version="1.0" encoding="UTF-8"?>
