@@ -7,10 +7,12 @@ from __future__ import absolute_import
 
 import datetime
 import pytest
+from astropy import units as u
 
 from sunpy.time import TimeRange
 from sunpy.net import vso
 from sunpy.net.vso import attrs as va
+from sunpy.net.vso.vso import QueryResponse
 from sunpy.net import attr
 
 def pytest_funcarg__eit(request):
@@ -110,35 +112,48 @@ def test_attror_and():
     assert one == other
 
 
+def test_wave_inputQuantity():
+    wrong_type_mesage = "Wave inputs must be astropy Quantities"
+    with pytest.raises(TypeError) as excinfo:
+        va.Wave(10, 23)
+    assert excinfo.value.message == wrong_type_mesage
+    with pytest.raises(TypeError) as excinfo:
+        va.Wave(10 * u.AA, 23)
+    assert excinfo.value.message == wrong_type_mesage
+
 def test_wave_toangstrom():
-    frequency = [
-        ('Hz', 1),
-        ('kHz', 1e3),
-        ('MHz', 1e6),
-        ('GHz', 1e9)]
+    # TODO: this test should test that inputs are in any of spectral units
+    # more than just converted to Angstroms.
+    frequency = [(1, 1 * u.Hz),
+                 (1e3, 1 * u.kHz),
+                 (1e6, 1 * u.MHz),
+                 (1e9, 1 * u.GHz)]
 
-    energy = [
-        ('eV', 1),
-        ('keV', 1e3),
-        ('MeV', 1e6)]
+    energy = [(1, 1 * u.eV),
+              (1e3, 1 * u.keV),
+              (1e6, 1 * u.MeV)]
 
-    for name, factor in energy:
-        w = va.Wave(62 / factor, 62 / factor, name)
-        assert int(w.min) == 199
+    for factor, unit in energy:
+        w = va.Wave((62 / factor) * unit, (62 / factor) * unit)
+        assert int(w.min.to(u.AA, u.equivalencies.spectral()).value) == 199
 
-    w = va.Wave(62, 62, 'eV')
-    assert int(w.min) == 199
-    w = va.Wave(62e-3, 62e-3, 'keV')
-    assert int(w.min) == 199
+    w = va.Wave(62 * u.eV, 62 * u.eV)
+    assert int(w.min.to(u.AA, u.equivalencies.spectral()).value) == 199
+    w = va.Wave(62e-3 * u.keV, 62e-3 * u.keV)
+    assert int(w.min.to(u.AA, u.equivalencies.spectral()).value) == 199
 
-    for name, factor in frequency:
-        w = va.Wave(1.506e16 / factor, 1.506e16 / factor, name)
-        assert int(w.min) == 199
+    for factor, unit in frequency:
+        w = va.Wave((1.506e16 / factor) * unit, (1.506e16 / factor) * unit)
+        assert int(w.min.to(u.AA, u.equivalencies.spectral()).value) == 199
 
-    w = va.Wave(1.506e16, 1.506e16, 'Hz')
-    assert int(w.min) == 199
-    w = va.Wave(1.506e7, 1.506e7, 'GHz')
-    assert int(w.min) == 199
+    w = va.Wave(1.506e16 * u.Hz, 1.506e16 * u.Hz)
+    assert int(w.min.to(u.AA, u.equivalencies.spectral()).value) == 199
+    w = va.Wave(1.506e7 * u.GHz, 1.506e7 * u.GHz)
+    assert int(w.min.to(u.AA, u.equivalencies.spectral()).value) == 199
+
+    with pytest.raises(ValueError) as excinfo:
+        va.Wave(10 * u.g, 23 * u.g)
+    assert excinfo.value.message == "'g' is not a spectral supported unit"
 
 
 def test_time_xor():
@@ -159,15 +174,15 @@ def test_time_xor():
 
 
 def test_wave_xor():
-    one = va.Wave(0, 1000)
-    a = one ^ va.Wave(200, 400)
+    one = va.Wave(0 * u.AA, 1000 * u.AA)
+    a = one ^ va.Wave(200 * u.AA, 400 * u.AA)
 
-    assert a == attr.AttrOr([va.Wave(0, 200), va.Wave(400, 1000)])
+    assert a == attr.AttrOr([va.Wave(0 * u.AA, 200 * u.AA), va.Wave(400 * u.AA, 1000 * u.AA)])
 
-    a ^= va.Wave(600, 800)
+    a ^= va.Wave(600 * u.AA, 800 * u.AA)
 
     assert a == attr.AttrOr(
-        [va.Wave(0, 200), va.Wave(400, 600), va.Wave(800, 1000)])
+        [va.Wave(0 * u.AA, 200 * u.AA), va.Wave(400 * u.AA, 600 * u.AA), va.Wave(800 * u.AA, 1000 * u.AA)])
 
 
 def test_err_dummyattr_create():
@@ -181,7 +196,15 @@ def test_err_dummyattr_apply():
 
 def test_wave_repr():
     """Tests the __repr__ method of class vso.attrs.Wave"""
-    wav = vso.attrs.Wave(12, 16)
-    moarwav = vso.attrs.Wave(15, 12, "Angstrom")
+    wav = vso.attrs.Wave(12 * u.AA, 16 * u.AA)
+    moarwav = vso.attrs.Wave(15 * u.AA, 12 * u.AA)
     assert repr(wav) == "<Wave(12.0, 16.0, 'Angstrom')>"
     assert repr(moarwav) == "<Wave(12.0, 15.0, 'Angstrom')>"
+
+def test_str():
+    qr = QueryResponse([])
+    assert str(qr) == 'Start Time End Time Source Instrument Type\n---------- -------- ------ ---------- ----'
+
+def test_repr():
+    qr = QueryResponse([])
+    assert "Start Time End Time  Source Instrument   Type" in repr(qr)
