@@ -3,6 +3,7 @@
 The following code is heavily based on IDL function get_sun.pro which itself
 is based on algorithms presented in the book Astronomical Formulae for
 Calculators, by Jean Meeus.
+Every function returning a quantity is of type astropy.units.Quantity
 
 A correct answer set to compare to
 
@@ -24,6 +25,7 @@ from __future__ import absolute_import
 import numpy as np
 
 import astropy.units as u
+from astropy.coordinates import Angle, Longitude, Latitude
 
 from sunpy.time import parse_time, julian_day, julian_centuries
 from sunpy.sun import constants
@@ -32,10 +34,10 @@ __all__ = ["print_params"
            ,"heliographic_solar_center"
            ,"solar_north"
            ,"apparent_declination"
-           ,"apparent_rightascenscion"
+           ,"apparent_rightascension"
            ,"apparent_obliquity_of_ecliptic"
            ,"true_declination"
-           ,"true_rightascenscion"
+           ,"true_rightascension"
            ,"true_obliquity_of_ecliptic"
            ,"apparent_latitude"
            ,"true_latitude"
@@ -58,6 +60,7 @@ __authors__ = ["Steven Christe"]
 __email__ = "steven.d.christe@nasa.gov"
 
 def solar_cycle_number(t='now'):
+    """Return the solar cycle number."""
     time = parse_time(t)
     result = (time.year + 8) % 28 + 1
     return result
@@ -78,14 +81,14 @@ def solar_semidiameter_angular_size(t='now'):
         Radius_{\odot}[rad]=\frac{<Radius_{\odot}[m]>}{D_{\odot \oplus}(t)[m]}
 
     """
-    solar_semidiameter_rad = constants.radius / (sunearth_distance(t) * constants.au)
-    return (np.rad2deg(solar_semidiameter_rad * u.rad)).to(u.arcsec)
+    solar_semidiameter_rad = (constants.radius.to(u.AU)) / sunearth_distance(t)
+    return Angle(solar_semidiameter_rad.to(u.arcsec, equivalencies = u.dimensionless_angles()))
 
 def position(t='now'):
     """Returns the position of the Sun (right ascension and declination)
     on the celestial sphere using the equatorial coordinate system in arcsec.
     """
-    ra = true_rightascenscion(t)
+    ra = true_rightascension(t)
     dec = true_declination(t)
     result = [ra,dec]
     return result
@@ -100,8 +103,8 @@ def mean_ecliptic_longitude(t='now'):
     """Returns the mean ecliptic longitude."""
     T = julian_centuries(t)
     result = 279.696680 + 36000.76892 * T + 0.0003025 * T ** 2
-    result = result % 360.0
-    return result
+    result = result * u.deg
+    return Longitude(result)
 
 def longitude_Sun_perigee(t='now'): # pylint: disable=W0613
     # T = julian_centuries(t)
@@ -112,8 +115,8 @@ def mean_anomaly(t='now'):
     assuming a circular orbit) as a function of time."""
     T = julian_centuries(t)
     result = 358.475830 + 35999.049750 * T - 0.0001500 * T ** 2 - 0.00000330 * T ** 3
-    result = result % 360.0
-    return result
+    result = result * u.deg
+    return Longitude(result)
 
 def carrington_rotation_number(t='now'):
     """Return the Carrington Rotation number"""
@@ -125,28 +128,29 @@ def geometric_mean_longitude(t='now'):
     """Returns the geometric mean longitude (in degrees)"""
     T = julian_centuries(t)
     result = 279.696680 + 36000.76892 * T + 0.0003025 * T ** 2
-    result = result % 360.0
-    return result
+    result = result * u.deg
+    return Longitude(result)
 
 def equation_of_center(t='now'):
     """Returns the Sun's equation of center (in degrees)"""
     T = julian_centuries(t)
     mna = mean_anomaly(t)
-    result = ((1.9194600 - 0.0047890 * T - 0.0000140 * T
-    ** 2) * np.sin(np.radians(mna)) + (0.0200940 - 0.0001000 * T) *
-    np.sin(np.radians(2 * mna)) + 0.0002930 * np.sin(np.radians(3 * mna)))
-    return result
+    result = ((1.9194600 - 0.0047890 * T - 0.0000140 * T ** 2) * np.sin(mna)
+    + (0.0200940 - 0.0001000 * T) *
+    np.sin(2 * mna) + 0.0002930 * np.sin(3 * mna))
+    result = result * u.deg
+    return Angle(result)
 
 def true_longitude(t='now'):
     """Returns the Sun's true geometric longitude (in degrees)
-    (Refered to the mean equinox of date.  Question: Should the higher
+    (Referred to the mean equinox of date.  Question: Should the higher
     accuracy terms from which app_long is derived be added to true_long?)"""
-    result = (equation_of_center(t) + geometric_mean_longitude(t)) % 360.0
-    return result
+    result = equation_of_center(t) + geometric_mean_longitude(t)
+    return Longitude(result)
 
 def true_anomaly(t='now'):
-    """Returns the Sun's true anomaly (in degress)."""
-    result = (mean_anomaly(t) + equation_of_center(t)) % 360.0
+    """Returns the Sun's true anomaly (in degrees)."""
+    result = (mean_anomaly(t) + equation_of_center(t)) % (360.0 * u.deg)
     return result
 
 def sunearth_distance(t='now'):
@@ -154,102 +158,100 @@ def sunearth_distance(t='now'):
     accuracy terms not included here."""
     ta = true_anomaly(t)
     e = eccentricity_SunEarth_orbit(t)
-    result = 1.00000020 * (1.0 - e ** 2) / (1.0 + e * np.cos(np.radians(ta)))
-    return result
+    result = 1.00000020 * (1.0 - e ** 2) / (1.0 + e * np.cos(ta))
+    return result * u.AU
 
 def apparent_longitude(t='now'):
     """Returns the apparent longitude of the Sun."""
     T = julian_centuries(t)
-    omega = 259.18 - 1934.142 * T
+    omega = (259.18 - 1934.142 * T) * u.deg
     true_long = true_longitude(t)
-    result = true_long - 0.00569 - 0.00479 * np.sin(np.radians(omega))
-    return result
+    result = true_long - (0.00569 - 0.00479 * np.sin(omega)) * u.deg
+    return Longitude(result)
 
 def true_latitude(t='now'): # pylint: disable=W0613
-    '''Returns the true latitude. Never more than 1.2 arcsec from 0,
-    set to 0 here.'''
+    """Returns the true latitude. Never more than 1.2 arcsec from 0,
+    set to 0 here."""
     return 0.0
 
 def apparent_latitude(t='now'): # pylint: disable=W0613
+    """Returns the true latitude. Set to 0 here."""
     return 0
 
 def true_obliquity_of_ecliptic(t='now'):
+    """Returns the true obliquity of the ecliptic."""
     T = julian_centuries(t)
     result = 23.452294 - 0.0130125 * T - 0.00000164 * T ** 2 + 0.000000503 * T ** 3
-    return result
+    return Angle(result, u.deg)
 
-def true_rightascenscion(t='now'):
+def true_rightascension(t='now'):
+    """Return the true right ascension."""
     true_long = true_longitude(t)
     ob = true_obliquity_of_ecliptic(t)
-    result = np.cos(np.radians(ob)) * np.sin(np.radians(true_long))
-    return result
+    result = np.cos(ob) * np.sin(true_long)
+    result = result * u.deg
+    return Longitude(result)
 
 def true_declination(t='now'):
-    result = np.cos(np.radians(true_longitude(t)))
-    return result
+    """Return the true declination."""
+    result = np.cos(true_longitude(t))
+    result = result * u.deg
+    return Latitude(result)
 
 def apparent_obliquity_of_ecliptic(t='now'):
+    """Return the apparent obliquity of the ecliptic."""
     omega = apparent_longitude(t)
-    result = true_obliquity_of_ecliptic(t) + 0.00256 * np.cos(np.radians(omega))
+    result = true_obliquity_of_ecliptic(t) + (0.00256 * np.cos(omega)) * u.deg
     return result
 
-def apparent_rightascenscion(t='now'):
-    """Returns the apparent right ascenscion of the Sun."""
-    y = np.cos(np.radians(apparent_obliquity_of_ecliptic(t))) * np.sin(np.radians(apparent_longitude(t)))
-    x = np.cos(np.radians(apparent_longitude(t)))
-    rpol = np.rad2deg(np.arctan2(y, x))
-    app_ra = rpol % 360.0
-    if app_ra < 0: app_ra += 360.0
-    result = app_ra/15.0
-    return result
+def apparent_rightascension(t='now'):
+    """Returns the apparent right ascension of the Sun."""
+    y = np.cos(apparent_obliquity_of_ecliptic(t)) * np.sin(apparent_longitude(t))
+    x = np.cos(apparent_longitude(t))
+    app_ra = np.arctan2(y, x)
+    return Longitude(app_ra.to(u.hourangle))
 
 def apparent_declination(t='now'):
     """Returns the apparent declination of the Sun."""
     ob = apparent_obliquity_of_ecliptic(t)
     app_long = apparent_longitude(t)
-    result = np.degrees(np.arcsin(np.sin(np.radians(ob))) * np.sin(np.radians(app_long)))
-    return result
+    result = np.degrees(np.arcsin(np.sin(ob)) * np.sin(app_long))
+    return Latitude(result)
 
 def solar_north(t='now'):
     """Returns the position of the Solar north pole in degrees."""
     T = julian_centuries(t)
     ob1 = true_obliquity_of_ecliptic(t)
     # in degrees
-    i = 7.25
-    k = 74.3646 + 1.395833 * T
-    lamda = true_longitude(t) - 0.00569
+    i = 7.25 * u.deg
+    k = (74.3646 + 1.395833 * T) * u.deg
+    lamda = true_longitude(t) - (0.00569 * u.deg)
     omega = apparent_longitude(t)
-    lamda2 = lamda - 0.00479 * np.sin(np.radians(omega))
-    diff = np.radians(lamda - k)
-    x = np.degrees(np.arctan(-np.cos(np.radians(lamda2)*np.tan(np.radians(ob1)))))
-    y = np.degrees(np.arctan(-np.cos(diff) * np.tan(np.radians(i))))
+    lamda2 = lamda - (0.00479 * np.sin(omega)) * u.deg
+    diff = lamda - k
+    x = np.arctan(-np.cos((lamda2) * np.tan(ob1)))
+    y = np.arctan(-np.cos(diff) * np.tan(i))
     result = x + y
-    return result
+    return Angle(result.to(u.deg))
 
 def heliographic_solar_center(t='now'):
     """Returns the position of the solar center in heliographic coordinates."""
     jd = julian_day(t)
     T = julian_centuries(t)
     # Heliographic coordinates in degrees
-    theta = (jd - 2398220)*360/25.38
-    i = 7.25
-    k = 74.3646 + 1.395833 * T
-    lamda = true_longitude(t) - 0.00569
-    #omega = apparent_longitude(t)
-    #lamda2 = lamda - 0.00479 * math.sin(np.radians(omega))
-    diff = np.radians(lamda - k)
+    theta = ((jd - 2398220)*360/25.38) * u.deg
+    i = 7.25 * u.deg
+    k = (74.3646 + 1.395833 * T) * u.deg
+    lamda = true_longitude(t) - 0.00569 * u.deg
+    diff = lamda - k
     # Latitude at center of disk (deg):
-    he_lat = np.degrees(np.arcsin(np.sin(diff)*np.sin(np.radians(i))))
+    he_lat = np.degrees(np.arcsin(np.sin(diff)*np.sin(i)))
     # Longitude at center of disk (deg):
-    y = -np.sin(diff)*np.cos(np.radians(i))
+    y = -np.sin(diff)*np.cos(i)
     x = -np.cos(diff)
-    rpol = np.rad2deg(np.arctan2(y, x))
+    rpol = (np.arctan2(y, x))
     he_lon = rpol - theta
-    he_lon = he_lon % 360
-    if he_lon < 0:
-        he_lon = he_lon + 360.0
-
-    return [he_lon, he_lat]
+    return [Longitude(he_lon), Latitude(he_lat)]
 
 def print_params(t='now'):
     """Print out a summary of Solar ephemeris"""
@@ -262,9 +264,9 @@ def print_params(t='now'):
                                                  + str(true_latitude(t)) + ')')
     print('Apparent (long, lat) in degrees = (' + str(apparent_longitude(t)) + ','
                                                  + str(apparent_latitude(t)) + ')')
-    print('True (RA, Dec) = (' + str(true_rightascenscion(t)) + ','
+    print('True (RA, Dec) = (' + str(true_rightascension(t)) + ','
           + str(true_declination(t)))
-    print('Apparent (RA, Dec) = (' + str(apparent_rightascenscion(t)) + ','
+    print('Apparent (RA, Dec) = (' + str(apparent_rightascension(t)) + ','
           + str(apparent_declination(t)))
     print('Heliographic long. and lat of disk center in deg = (' + str(heliographic_solar_center(t)) + ')')
     print('Position angle of north pole in deg = ' + str(solar_north(t)))
