@@ -9,7 +9,8 @@ except ImportError:
 
 
 def main(modulename='', coverage=False, cov_report=False,
-         online=False, offline=True, verbose=False, parallel=0, args=None):
+         online=False, offline=True, figure=False, verbose=False,
+         parallel=0, args=None):
     """
     Execute the test suite of the sunpy package. The parameters may be
     used to restrict the number of tests that will be executed or to
@@ -35,6 +36,9 @@ def main(modulename='', coverage=False, cov_report=False,
     offline: bool
         Run the tests that don't require an internet connection.
 
+    figure: bool
+        Include the figure tests in the test run.
+
     """
     print modulename
     if pytest is None:
@@ -65,6 +69,8 @@ def main(modulename='', coverage=False, cov_report=False,
         all_args.append('-k-online')
     if not offline:
         all_args.append('-k online')
+    if not figure:
+        all_args.append('-m not figure')
     all_args.append(path)
 
     if args:
